@@ -20,6 +20,7 @@ class SeedMetricsLayer:
         run_query_override=None,
     ):
         self.default_model_name = "base_model"
+        self.run_query_override = run_query_override
         self.profile_name = profile
         self.target_name = target
         if metrics_layer is None:
@@ -295,6 +296,7 @@ class SeedMetricsLayer:
 
         connections = MetricsLayerConnection.get_connections_from_profile(profile_name, target)
         metrics_layer = MetricsLayerConnection(location=SeedMetricsLayer._location(), connections=connections)
+        metrics_layer.load()
         return metrics_layer
 
     @staticmethod
